==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkDendrogramItem.java <==
// java wrapper for vtkDendrogramItem object
//

package vtk;
import vtk.*;

public class vtkDendrogramItem extends vtkContextItem
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetTree_2(vtkTree id0);
  public void SetTree(vtkTree id0)
    { SetTree_2(id0); }

  private native long GetTree_3();
  public vtkTree GetTree() {
    long temp = GetTree_3();

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CollapseToNumberOfLeafNodes_4(int id0);
  public void CollapseToNumberOfLeafNodes(int id0)
    { CollapseToNumberOfLeafNodes_4(id0); }

  private native long GetPrunedTree_5();
  public vtkTree GetPrunedTree() {
    long temp = GetPrunedTree_5();

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetColorArray_6(String id0);
  public void SetColorArray(String id0)
    { SetColorArray_6(id0); }

  private native void SetExtendLeafNodes_7(boolean id0);
  public void SetExtendLeafNodes(boolean id0)
    { SetExtendLeafNodes_7(id0); }

  private native boolean GetExtendLeafNodes_8();
  public boolean GetExtendLeafNodes()
    { return GetExtendLeafNodes_8(); }

  private native void ExtendLeafNodesOn_9();
  public void ExtendLeafNodesOn()
    { ExtendLeafNodesOn_9(); }

  private native void ExtendLeafNodesOff_10();
  public void ExtendLeafNodesOff()
    { ExtendLeafNodesOff_10(); }

  private native void SetOrientation_11(int id0);
  public void SetOrientation(int id0)
    { SetOrientation_11(id0); }

  private native int GetOrientation_12();
  public int GetOrientation()
    { return GetOrientation_12(); }

  private native double GetAngleForOrientation_13(int id0);
  public double GetAngleForOrientation(int id0)
    { return GetAngleForOrientation_13(id0); }

  private native double GetTextAngleForOrientation_14(int id0);
  public double GetTextAngleForOrientation(int id0)
    { return GetTextAngleForOrientation_14(id0); }

  private native void SetDrawLabels_15(boolean id0);
  public void SetDrawLabels(boolean id0)
    { SetDrawLabels_15(id0); }

  private native boolean GetDrawLabels_16();
  public boolean GetDrawLabels()
    { return GetDrawLabels_16(); }

  private native void DrawLabelsOn_17();
  public void DrawLabelsOn()
    { DrawLabelsOn_17(); }

  private native void DrawLabelsOff_18();
  public void DrawLabelsOff()
    { DrawLabelsOff_18(); }

  private native void SetPosition_19(double id0,double id1);
  public void SetPosition(double id0,double id1)
    { SetPosition_19(id0,id1); }

  private native void SetPosition_20(double id0[]);
  public void SetPosition(double id0[])
    { SetPosition_20(id0); }

  private native double[] GetPosition_21();
  public double[] GetPosition()
    { return GetPosition_21(); }

  private native double GetLeafSpacing_22();
  public double GetLeafSpacing()
    { return GetLeafSpacing_22(); }

  private native void SetLeafSpacing_23(double id0);
  public void SetLeafSpacing(double id0)
    { SetLeafSpacing_23(id0); }

  private native void PrepareToPaint_24(vtkContext2D id0);
  public void PrepareToPaint(vtkContext2D id0)
    { PrepareToPaint_24(id0); }

  private native void GetBounds_25(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_25(id0); }

  private native void ComputeLabelWidth_26(vtkContext2D id0);
  public void ComputeLabelWidth(vtkContext2D id0)
    { ComputeLabelWidth_26(id0); }

  private native double GetLabelWidth_27();
  public double GetLabelWidth()
    { return GetLabelWidth_27(); }

  private native boolean GetPositionOfVertex_28(String id0,double id1[]);
  public boolean GetPositionOfVertex(String id0,double id1[])
    { return GetPositionOfVertex_28(id0,id1); }

  private native boolean Paint_29(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_29(id0); }

  private native double GetLineWidth_30();
  public double GetLineWidth()
    { return GetLineWidth_30(); }

  private native void SetLineWidth_31(double id0);
  public void SetLineWidth(double id0)
    { SetLineWidth_31(id0); }

  private native void SetDisplayNumberOfCollapsedLeafNodes_32(boolean id0);
  public void SetDisplayNumberOfCollapsedLeafNodes(boolean id0)
    { SetDisplayNumberOfCollapsedLeafNodes_32(id0); }

  private native boolean GetDisplayNumberOfCollapsedLeafNodes_33();
  public boolean GetDisplayNumberOfCollapsedLeafNodes()
    { return GetDisplayNumberOfCollapsedLeafNodes_33(); }

  private native void DisplayNumberOfCollapsedLeafNodesOn_34();
  public void DisplayNumberOfCollapsedLeafNodesOn()
    { DisplayNumberOfCollapsedLeafNodesOn_34(); }

  private native void DisplayNumberOfCollapsedLeafNodesOff_35();
  public void DisplayNumberOfCollapsedLeafNodesOff()
    { DisplayNumberOfCollapsedLeafNodesOff_35(); }

  private native String GetDistanceArrayName_36();
  public String GetDistanceArrayName()
    { return GetDistanceArrayName_36(); }

  private native void SetDistanceArrayName_37(String id0);
  public void SetDistanceArrayName(String id0)
    { SetDistanceArrayName_37(id0); }

  private native String GetVertexNameArrayName_38();
  public String GetVertexNameArrayName()
    { return GetVertexNameArrayName_38(); }

  private native void SetVertexNameArrayName_39(String id0);
  public void SetVertexNameArrayName(String id0)
    { SetVertexNameArrayName_39(id0); }

  public vtkDendrogramItem() { super(); }

  public vtkDendrogramItem(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkDendrogramItem.java <==
// java wrapper for vtkDendrogramItem object
//

package vtk;
import vtk.*;

public class vtkDendrogramItem extends vtkContextItem
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetTree_2(vtkTree id0);
  public void SetTree(vtkTree id0)
    { SetTree_2(id0); }

  private native long GetTree_3();
  public vtkTree GetTree() {
    long temp = GetTree_3();

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CollapseToNumberOfLeafNodes_4(int id0);
  public void CollapseToNumberOfLeafNodes(int id0)
    { CollapseToNumberOfLeafNodes_4(id0); }

  private native long GetPrunedTree_5();
  public vtkTree GetPrunedTree() {
    long temp = GetPrunedTree_5();

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetColorArray_6(String id0);
  public void SetColorArray(String id0)
    { SetColorArray_6(id0); }

  private native void SetExtendLeafNodes_7(boolean id0);
  public void SetExtendLeafNodes(boolean id0)
    { SetExtendLeafNodes_7(id0); }

  private native boolean GetExtendLeafNodes_8();
  public boolean GetExtendLeafNodes()
    { return GetExtendLeafNodes_8(); }

  private native void ExtendLeafNodesOn_9();
  public void ExtendLeafNodesOn()
    { ExtendLeafNodesOn_9(); }

  private native void ExtendLeafNodesOff_10();
  public void ExtendLeafNodesOff()
    { ExtendLeafNodesOff_10(); }

  private native void SetOrientation_11(int id0);
  public void SetOrientation(int id0)
    { SetOrientation_11(id0); }

  private native int GetOrientation_12();
  public int GetOrientation()
    { return GetOrientation_12(); }

  private native double GetAngleForOrientation_13(int id0);
  public double GetAngleForOrientation(int id0)
    { return GetAngleForOrientation_13(id0); }

  private native double GetTextAngleForOrientation_14(int id0);
  public double GetTextAngleForOrientation(int id0)
    { return GetTextAngleForOrientation_14(id0); }

  private native void SetDrawLabels_15(boolean id0);
  public void SetDrawLabels(boolean id0)
    { SetDrawLabels_15(id0); }

  private native boolean GetDrawLabels_16();
  public boolean GetDrawLabels()
    { return GetDrawLabels_16(); }

  private native void DrawLabelsOn_17();
  public void DrawLabelsOn()
    { DrawLabelsOn_17(); }

  private native void DrawLabelsOff_18();
  public void DrawLabelsOff()
    { DrawLabelsOff_18(); }

  private native void SetPosition_19(double id0,double id1);
  public void SetPosition(double id0,double id1)
    { SetPosition_19(id0,id1); }

  private native void SetPosition_20(double id0[]);
  public void SetPosition(double id0[])
    { SetPosition_20(id0); }

  private native double[] GetPosition_21();
  public double[] GetPosition()
    { return GetPosition_21(); }

  private native double GetLeafSpacing_22();
  public double GetLeafSpacing()
    { return GetLeafSpacing_22(); }

  private native void SetLeafSpacing_23(double id0);
  public void SetLeafSpacing(double id0)
    { SetLeafSpacing_23(id0); }

  private native void PrepareToPaint_24(vtkContext2D id0);
  public void PrepareToPaint(vtkContext2D id0)
    { PrepareToPaint_24(id0); }

  private native void GetBounds_25(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_25(id0); }

  private native void ComputeLabelWidth_26(vtkContext2D id0);
  public void ComputeLabelWidth(vtkContext2D id0)
    { ComputeLabelWidth_26(id0); }

  private native double GetLabelWidth_27();
  public double GetLabelWidth()
    { return GetLabelWidth_27(); }

  private native boolean GetPositionOfVertex_28(String id0,double id1[]);
  public boolean GetPositionOfVertex(String id0,double id1[])
    { return GetPositionOfVertex_28(id0,id1); }

  private native boolean Paint_29(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_29(id0); }

  private native double GetLineWidth_30();
  public double GetLineWidth()
    { return GetLineWidth_30(); }

  private native void SetLineWidth_31(double id0);
  public void SetLineWidth(double id0)
    { SetLineWidth_31(id0); }

  private native void SetDisplayNumberOfCollapsedLeafNodes_32(boolean id0);
  public void SetDisplayNumberOfCollapsedLeafNodes(boolean id0)
    { SetDisplayNumberOfCollapsedLeafNodes_32(id0); }

  private native boolean GetDisplayNumberOfCollapsedLeafNodes_33();
  public boolean GetDisplayNumberOfCollapsedLeafNodes()
    { return GetDisplayNumberOfCollapsedLeafNodes_33(); }

  private native void DisplayNumberOfCollapsedLeafNodesOn_34();
  public void DisplayNumberOfCollapsedLeafNodesOn()
    { DisplayNumberOfCollapsedLeafNodesOn_34(); }

  private native void DisplayNumberOfCollapsedLeafNodesOff_35();
  public void DisplayNumberOfCollapsedLeafNodesOff()
    { DisplayNumberOfCollapsedLeafNodesOff_35(); }

  private native String GetDistanceArrayName_36();
  public String GetDistanceArrayName()
    { return GetDistanceArrayName_36(); }

  private native void SetDistanceArrayName_37(String id0);
  public void SetDistanceArrayName(String id0)
    { SetDistanceArrayName_37(id0); }

  private native String GetVertexNameArrayName_38();
  public String GetVertexNameArrayName()
    { return GetVertexNameArrayName_38(); }

  private native void SetVertexNameArrayName_39(String id0);
  public void SetVertexNameArrayName(String id0)
    { SetVertexNameArrayName_39(id0); }

  public vtkDendrogramItem() { super(); }

  public vtkDendrogramItem(long id) { super(id); }
  public native long   VTKInit();

}
